peyutil
=======


<code>peyutil</code> is a package of basic utility functions that is used by 
the deconstructed packages that used to make up [peyotl](https://github.com/OpenTreeOfLife/peyotl).
This package probably not of great use to external developers by itself, it
is a prerequisite for the peyotl package.


Instructions
------------

::

    python3 -mvenv env
    source env/bin/activate
    pip install -r requirements.txt
    python setup.py develop
    python setup.py test

performs the basic installation and test.

Thanks
------

Thanks to NSF_ and HITS_ for funding support.

peyutil is primarily written by Mark Holder, Emily Jane McTavish, and Jim Allman,
but see the CONTRIBUTORS_ file for a more complete list
of people who have contributed code.


****************

.. _Open Tree of Life project: https://opentreeoflife.github.io
.. _CONTRIBUTORS: https://raw.githubusercontent.com/OpenTreeOfLife/peyutil/master/CONTRIBUTORS.txt
.. _NSF: http://www.nsf.gov
.. _HITS: http://www.h-its.org/english
.. _NESCent: http://kb.phenoscape.org
